%global intel_mpi_bench_vers IMB-v2021.3
%global osu_micro_bench_vers 5.8

Summary:    MPI Benchmarks and tests
Name:       mpitests
Version:    5.8
Release:    6%{?dist}
License:    CPL and BSD
URL:        http://www.openfabrics.org
Source0:    https://github.com/intel/mpi-benchmarks/archive/%{intel_mpi_bench_vers}.tar.gz
Source1:    http://mvapich.cse.ohio-state.edu/download/mvapich/osu-micro-benchmarks-%{osu_micro_bench_vers}.tgz

BuildRequires: automake autoconf libtool gcc gcc-c++
BuildRequires: hwloc-devel libibmad-devel rdma-core-devel


%description
A set of popular MPI benchmarks:
Intel MPI benchmarks %{intel_mpi_bench_vers}.
OSU micro-benchmarks %{osu_micro_bench_vers}.

%package openmpi
Summary:       MPI tests package compiled against openmpi
BuildRequires: openmpi-devel
Requires:      openmpi

%description openmpi
MPI test suite compiled against the openmpi package

%package mpich
Summary:       MPI tests package compiled against mpich
BuildRequires: mpich-devel >= 3.2.1-8
Requires:      mpich

%description mpich
MPI test suite compiled against the mpich package

%package mvapich2
Summary:       MPI tests package compiled against mvapich2
BuildRequires: mvapich2-devel
Requires:      mvapich2

%description mvapich2
MPI test suite compiled against the mvapich2 package

%ifarch x86_64
%package mvapich2-psm2
Summary:       MPI tests package compiled against mvapich2 using OmniPath
BuildRequires: mvapich2-psm2-devel libpsm2-devel
Requires:      mvapich2-psm2

%description mvapich2-psm2
MPI test suite compiled against the mvapich2 package using OmniPath
%endif

%prep
%autosetup -c -a 1


%build
export CC=mpicc
export CXX=mpicxx
export FC=mpif90
export F77=mpif77
export CFLAGS="%{optflags} -fno-strict-aliasing -fPIC"
export CXXFLAGS="%{optflags} -fno-strict-aliasing -fPIC"
do_build() {
  mkdir build-$MPI_COMPILER
  cp -al mpi-benchmarks-%{intel_mpi_bench_vers} osu-micro-benchmarks-%{osu_micro_bench_vers} build-$MPI_COMPILER
  cd build-$MPI_COMPILER/mpi-benchmarks-%{intel_mpi_bench_vers}
  make OPTFLAGS="%{build_cflags}" LDFLAGS="%{build_ldflags}" MPI_HOME="$MPI_HOME" all
  cd ../osu-micro-benchmarks-%{osu_micro_bench_vers}
  autoreconf -vif
  %configure
  %make_build
  cd ../..
}

%{_openmpi_load}
do_build
%{_openmpi_unload}

%{_mpich_load}
do_build
%{_mpich_unload}

%{_mvapich2_load}
do_build
%{_mvapich2_unload}

%ifarch x86_64
%{_mvapich2_psm2_load}
do_build
%{_mvapich2_psm2_unload}
%endif


%install
do_install() {
  mkdir -p %{buildroot}$MPI_BIN
  cd build-$MPI_COMPILER/osu-micro-benchmarks-%{osu_micro_bench_vers}
  %make_install DESTDIR=%{buildroot}/staging
  find %{buildroot}/staging -name 'osu_*' -type f -perm -111 | while read X; do
    mv $X %{buildroot}$MPI_BIN/mpitests-$(basename $X)
  done
  cd ../mpi-benchmarks-%{intel_mpi_bench_vers}/
  for X in IMB-*; do
    cp $X %{buildroot}$MPI_BIN/mpitests-$X
  done
  cd ../..
}

%{_openmpi_load}
do_install
%{_openmpi_unload}

%{_mpich_load}
do_install
%{_mpich_unload}

%{_mvapich2_load}
do_install
%{_mvapich2_unload}

%ifarch x86_64
%{_mvapich2_psm2_load}
do_install
%{_mvapich2_psm2_unload}
%endif


%files openmpi
%{_libdir}/openmpi/bin/mpitests-*

%files mpich
%{_libdir}/mpich/bin/mpitests-*

%files mvapich2
%{_libdir}/mvapich2/bin/mpitests-*

%ifarch x86_64
%files mvapich2-psm2
%{_libdir}/mvapich2-psm2/bin/mpitests-*
%endif

%changelog
* Thu Sep 26 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 5.8-6
- Rebuilt for clarifying the packages requirement in BaseOS and AppStream

* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 5.8-5
- Rebuilt for loongarch release

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 5.8-4
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 5.8-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 5.8-2
- Rebuilt for OpenCloudOS Stream 23

* Wed Mar 29 2023 Miaojun Dong <zoedong@tencent.com> - 5.8-1
- initial build
